@@ -1,7 +1,7 @@
 package Bencher;
 
 our $DATE = '2017-01-25'; # DATE
-our $VERSION = '1.027'; # VERSION
+our $VERSION = '1.028'; # VERSION
 
 1;
 # ABSTRACT: A benchmark framework
@@ -18,7 +18,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 1.027 of Bencher (from Perl distribution Bencher), released on 2017-01-25.
+This document describes version 1.028 of Bencher (from Perl distribution Bencher), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -199,7 +199,7 @@ running the benchmark scenario so you don't have to require them manually in
 your code/code template.
 
 The difference with the C<modules> property is: the modules specified in
-C<modules> should be specified as phase=x_benchmarks, rel=x_benchmarked
+C<modules> should be specified as phase=x_benchmarks, rel=x_benchmarks
 prerequisites while modules specified in C<helper_modules> should not. But all
 modules can be specified as phase=x_benchmarks, rel=requires prerequisites.
 
